##  Fact Sheet Description
You can modify the descriptions of fact sheet types and their translations into other languages. These descriptions help users, especially those who use the application infrequently, understand the differences between fact sheet types and how to use each one. You can include organization-specific details in the descriptions to provide additional context.
To modify a fact sheet description, follow these steps:
  1. On the fact sheet configuration page, go to the Fields tab.
  2. Select the fact sheet header, or click Edit on the header.
  3. On the right-side panel, go to the Translations tab.
  4. Modify the description in the Help text (optional) field as needed. You can generate descriptions and translate them into other languages using AI capabilities. For more information, see [AI-Supported Translation](https://help.sap.com/docs/leanix/ea/base-ai-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758e1767a441014b89cdbb68f4cded0__ai-supported_translation).
  5. Save the changes.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274182537a441014911490b72c51c212_LowRes.gif)
